@@ -1,6 +1,6 @@
 from .problem import Problem
 from .utils import ConfigDictionary
-from .job import JobSimple
+from .job import Job
 from .population import Population
 from .individual import Individual,GeneticIndividual
 from .operators import RandomGeneration
@@ -31,30 +31,6 @@ class Algorithm(metaclass=ABCMeta):
         self.options.declare(name='n_iterations', default=10,
                              desc='Max number of iterations')
 
-        # initial population size
-        self.population_size = 0
-
-        # set random generator
-        self.generator = RandomGeneration(self.problem.parameters)
-        self.generator.init(10)
-
-    @abstractmethod
-    def run(self):
-        pass
-
-    def gen_initial_population(self, is_archive=False):
-        individuals = self.generator.generate()
-        # set current size
-        self.population_size = len(individuals)
-        # evaluate individuals
-        self.evaluate(individuals)
-
-        if is_archive:
-            population = Population(individuals, individuals)
-        else:
-            population = Population(individuals)
-        return population
-
     def evaluate(self, individuals: list):
         if self.options["max_processes"] > 1:
             self.evaluate_parallel(individuals)
@@ -69,16 +45,15 @@ class Algorithm(metaclass=ABCMeta):
             if isinstance(individual, GeneticIndividual):
                 individual.transform_data(self.problem.signs)
 
-
     def evaluate_serial(self, individuals: list):
-        job = JobSimple(self.problem)
+        job = Job(self.problem)
         for individual in individuals:
             if individual.state == Individual.State.EMPTY:
                 job.evaluate(individual)
 
     def evaluate_parallel(self, individuals: list):
         # simple parallel loop
-        job = JobSimple(self.problem)
+        job = Job(self.problem)
         Parallel(n_jobs=self.options["max_processes"], verbose=1, require='sharedmem')(delayed(job.evaluate)(individual)
                                                                                        for individual in individuals)
 
@@ -111,3 +86,4 @@ class DummyAlgorithm(Algorithm):
 
     def run(self):
         pass
+
