@@ -10,8 +10,6 @@ import sys
 
 from copy import deepcopy
 
-EPSILON = sys.float_info.epsilon
-
 
 class GeneralEvolutionaryAlgorithm(Algorithm):
     """ Basis Class for evolutionary algorithms """
@@ -25,6 +23,32 @@ class GeneralEvolutionaryAlgorithm(Algorithm):
         self.mutator = None
         self.crossover = None
 
+        # initial population size
+        self.population_size = 0
+
+        # set random generator
+        self.generator = RandomGeneration(self.problem.parameters)
+        # self.generator.init(10)
+
+    def gen_initial_population(self, is_archive=False):
+        individuals = self.generator.generate()
+
+        # create population
+        if is_archive:
+            population = Population(individuals, individuals)
+        else:
+            population = Population(individuals)
+
+        # append to population
+        self.problem.populations.append(population)
+
+        # set current size
+        self.population_size = len(individuals)
+        # evaluate individuals
+        self.evaluate(individuals)
+
+        return population
+
     def run(self):
         pass
 
@@ -120,18 +144,18 @@ class NSGAII(GeneticAlgorithm):
             self.evaluate(gradient_population.individuals)
             self.evaluate_gradient(population.individuals, gradient_population.individuals)
 
-        # write to data store
-        self.problem.data_store.write_population(population)
-
         t_s = time.time()
         self.problem.logger.info(
-            "NSGA_II: {}/{}".format(self.options['max_population_number'], self.options['max_population_number'] * self.population_size))
+            "NSGA_II: {}/{}".format(self.options['max_population_number'],
+                                    self.options['max_population_number'] * self.population_size))
 
         # optimization
         for it in range(self.options['max_population_number']):
             # generate new offsprings
             offsprings = self.generate(population.individuals)
             # evaluate the offsprings
+            population = Population(offsprings)
+            self.problem.populations.append(population)
             self.evaluate(offsprings)
 
             # if (self.options['calculate_gradients'] is True) and population.number > 20:
@@ -147,11 +171,8 @@ class NSGAII(GeneticAlgorithm):
             # sort offsprings and ### remove duplicates by set!!!
             parents = sorted(set(offsprings), key=lambda x: (x.front_number, -x.crowding_distance))
 
-            # truncate
-            offsprings = parents[:self.population_size]
-
-            # write population
-            population = Population(offsprings)
+            # truncate and replace individuals
+            population.individuals = parents[:self.population_size]
 
             if self.options['calculate_gradients'] is True:
                 self.gradient_generator.init(population.individuals)
@@ -159,9 +180,6 @@ class NSGAII(GeneticAlgorithm):
                 self.evaluate(gradient_population.individuals)
                 self.evaluate_gradient(population.individuals, gradient_population.individuals)
 
-            # write popultation
-            self.problem.data_store.write_population(population)
-
         t = time.time() - t_s
         self.problem.logger.info("NSGA_II: elapsed time: {} s".format(t))
 
@@ -180,7 +198,8 @@ class EpsMOEA(GeneticAlgorithm):
 
     def run(self):
         # set random generator
-        self.generator = RandomGeneration(self.problem.parameters, individual_class=GeneticIndividual)  # the same as in the case of NSGA-II
+        self.generator = RandomGeneration(self.problem.parameters,
+                                          individual_class=GeneticIndividual)  # the same as in the case of NSGA-II
         self.generator.init(self.options['max_population_size'])
 
         # set crossover
@@ -189,8 +208,8 @@ class EpsMOEA(GeneticAlgorithm):
 
         # Part A: non-dominated sort of individuals
         # -----
-        selector_pareto = TournamentSelection(self.problem.parameters, self.problem.signs)
-        self.selector = TournamentSelection(self.problem.parameters, self.problem.signs)
+        selector_pareto = TournamentSelection(self.problem.parameters)
+        self.selector = TournamentSelection(self.problem.parameters)
         # the same as in the case of NSGA - ii
         # this operator is used to generate the new individuals
 
@@ -202,14 +221,11 @@ class EpsMOEA(GeneticAlgorithm):
 
         # Part B: eps-dominated sort of the individuals with archiving
         # -----
-        selector_epsdom = TournamentSelection(self.problem.parameters, self.problem.signs,
+        selector_epsdom = TournamentSelection(self.problem.parameters,
                                               dominance=EpsilonDominance, epsilons=self.options['epsilons'])
         selector_epsdom.sorting(population.archives)
         selector_epsdom.crowding_distance(population.archives)
 
-        # write to data store
-        self.problem.data_store.write_population(population) # TODO: modify the database connection to handle the archives
-
         t_s = time.time()
         self.problem.logger.info(
             "Eps-MOEA: {}/{}".format(self.options['max_population_number'], self.population_size))
@@ -217,20 +233,23 @@ class EpsMOEA(GeneticAlgorithm):
         # optimization
         for it in range(self.options['max_population_number']):
             # generate and evaluate the next generation
-            child = self.generate(population.individuals, population.archives)
-            self.evaluate(child)
+            children = self.generate(population.individuals, population.archives)
 
-            arch_child = deepcopy(child)
+            population = Population(children)
+            self.problem.populations.append(population)
+            self.evaluate(children)
+
+            arch_child = deepcopy(children)
             # PART A
             # non-dominated sorting of the newly generated and the older guys like in NSGA-ii
             # add the parents to the offsprings
-            child.extend(deepcopy(population.individuals))
+            children.extend(deepcopy(population.individuals))
 
             # non-dominated truncate on the guys
-            self.selector.sorting(child)
-            selector_pareto.crowding_distance(child)
+            self.selector.sorting(children)
+            selector_pareto.crowding_distance(children)
 
-            parents = sorted(set(child), key=lambda x: (x.front_number, -x.crowding_distance))
+            parents = sorted(set(children), key=lambda x: (x.front_number, -x.crowding_distance))
             child = parents[:self.population_size]  # truncate
 
             # eps dominated truncate on the guys
@@ -238,12 +257,7 @@ class EpsMOEA(GeneticAlgorithm):
             selector_epsdom.crowding_distance(arch_child)
 
             arch_parents = sorted(set(arch_child), key=lambda x: (x.front_number, -x.crowding_distance))
-            arch_child = arch_parents[:self.population_size]  # truncate
-
-            # write population
-            population = Population(child, arch_child)
-            # TODO: modify the database connection to handle the archives
-            self.problem.data_store.write_population(population)
+            population.archives = arch_parents[:self.population_size]  # truncate
 
         t = time.time() - t_s
         self.problem.logger.info("Eps-MOEA: {} s".format(t))
