@@ -1,27 +1,23 @@
-from .algorithm import Algorithm
-from .job import JobSimple
+from .algorithm_genetic import GeneralEvolutionaryAlgorithm
+from .job import Job
 from .operators import GradientGeneration
 from .population import Population
 import time
 
 
-class SweepAlgorithm(Algorithm):
+class SweepAlgorithm(GeneralEvolutionaryAlgorithm):
     """
     Sweep Analysis
     """
 
-    def __init__(self, problem, generator=None, name='SweepAlgorithm'):
+    def __init__(self, problem, generator, name='SweepAlgorithm'):
         super().__init__(problem, name)
 
-        if generator is not None:
-            self.generator = generator
-
-        self.job = JobSimple(self.problem)
+        self.generator = generator
 
     def run(self):
         t_s = time.time()
-        self.problem.logger.info(
-            "Sweep: {}: {} individuals".format(self.generator.__class__.__name__, self.population_size))
+        # self.problem.logger.info("Sweep: {}: {} individuals".format(self.generator.__class__.__name__, self.population_size))
 
         # create initial population and evaluate individuals
         population = self.gen_initial_population()
@@ -34,8 +30,5 @@ class SweepAlgorithm(Algorithm):
             gradient_population.individuals = self.evaluate(gradient_population.individuals)
             population.individuals = self.evaluate_gradient(population.individuals, gradient_population.individuals)
 
-        # write population
-        self.problem.data_store.write_population(population)
-
         t = time.time() - t_s
         self.problem.logger.info("Sweep: elapsed time: {} s".format(t))
