@@ -1,16 +1,14 @@
 import os
 import getpass
 from appdirs import user_config_dir
+import pathlib
 
 # internal variables
-
-path = __file__
-path = path.replace("config.py", "")
+__id__ = "artap"
+path = str(pathlib.Path(__file__).parent.absolute())
 
 artap_root = path
-tests_root = os.path.abspath(path + "." + os.sep + "tests" + os.sep)
-
-__artap__root = ""
+tests_root = os.path.abspath(path + os.sep + "tests" + os.sep)
 
 # config
 config = {}
@@ -29,5 +27,4 @@ config["server_keep_live_delay"] = 0.1
 # user config
 fn = "{}/config.py".format(user_config_dir(__id__))
 if os.path.exists(fn):
-    exec(open(fn).read())
-
+    exec(open(fn).read())
\ No newline at end of file
