@@ -16,7 +16,7 @@ problem.data_store = FileDataStore(problem, database_name=database_name, mode="r
 results = Results(problem)
 
 ind = 0
-for population in problem.data_store.populations:
+for population in problem.populations:
     ind = ind + len(population.individuals)
 
 print("individuals = {}".format(ind))
@@ -33,7 +33,7 @@ import csv
 with open('tmp/results.csv', 'w', newline='') as csvfile:
     spamwriter = csv.writer(csvfile, delimiter=';', quotechar='|', quoting=csv.QUOTE_MINIMAL)
 
-    for population in problem.data_store.populations:
+    for population in problem.populations:
         for individual in population.individuals:
             spamwriter.writerow([individual.vector[0], individual.vector[1], individual.vector[2], individual.vector[3],
                                  individual.costs[0]])
