@@ -4,6 +4,7 @@ from artap.results import Results
 
 import matplotlib.pyplot as plt
 
+
 class BiObjectiveTestProblem(Problem):
     """
     The goal of this example to show, how we can use Artap to solve a simple,
@@ -31,28 +32,25 @@ class BiObjectiveTestProblem(Problem):
     """
 
     def set(self):
-
         # Not mandatory to give a name for the test problem
         self.name = 'Biobjective Test Problem'
         self.working_dir = '.'
         # Defines x_1 and x_2, which are the optimized parameters
         # and the bounds 'defines' the constraints of the optimization problem
         # nsga -- ii algorithm doesn't need an initial value for the definition
-        self.parameters = [{'name':'x_1', 'bounds': [0.1, 1.]},
-                           {'name':'x_2', 'bounds': [0.0, 5.0]}]
+        self.parameters = [{'name': 'x_1', 'bounds': [0.1, 1.]},
+                           {'name': 'x_2', 'bounds': [0.0, 5.0]}]
 
         # The two, separate optimization functions and the direction of the optimization
         # is set to minimization. It is also possible to use the maximize keyword.
         self.costs = [{'name': 'f_1', 'criteria': 'minimize'},
                       {'name': 'f_2', 'criteria': 'minimize'}]
 
-
     def evaluate(self, individual):
-
         # The individual.vector function contains the problem parameters in the appropriate (previously defined) order
         f1 = individual.vector[0]
-        f2 = (1+individual.vector[1])/individual.vector[0]
-
+        f2 = (1 + individual.vector[1]) / individual.vector[0]
+        # individual.auxvar = [1.]
         return [f1, f2]
 
 
@@ -61,15 +59,15 @@ problem = BiObjectiveTestProblem()
 
 # Perform the optimization iterating over 100 times on 100 individuals.
 algorithm = NSGAII(problem)
-algorithm.options['max_population_number'] = 3
-algorithm.options['max_population_size'] = 10
+algorithm.options['max_population_number'] = 100
+algorithm.options['max_population_size'] = 100
 algorithm.run()
 
 # Post - processing the results
 # reads in the result values into the b, results class
 b = Results(problem)
-#print(b.parameters())
-b.write_out_populations()
+# print(b.parameters())
+# b.write_out_populations()
 solution = b.pareto_values()
 # Plotting out the resulting hyperbola with matplotlib
 plt.scatter([s[0] for s in solution],
