@@ -1,22 +1,23 @@
 import textwrap
 import re
-import rpyc
-from rpyc.core.async_ import AsyncResultTimeout
-from rpyc.utils.classic import upload_file, download_file
-import asyncio
 import tempfile
 import os
+import subprocess
 import datetime
 import time
 import ntpath
 from string import Template
-from xml.dom import minidom
-from artap.config import config
+
+import rpyc
+from rpyc.core.async_ import AsyncResultTimeout
+from rpyc.utils.classic import upload_file, download_file
 
 from abc import ABCMeta, abstractmethod
 from .utils import ConfigDictionary
 from shutil import copyfile
 
+from artap.config import config
+
 
 # parse ip address
 def parse_address(address):
@@ -99,20 +100,36 @@ class LocalComsolExecutor(Executor):
         param_names_string = Executor._join_parameters_names(self.problem.parameters)
         param_values_string = Executor._join_parameters_values(individual.vector)
 
-        run_string = self.comsol_command.substitute(input_file=self.model_file,
+        cmd_string = self.comsol_command.substitute(input_file=self.model_file,
                                                     param_names=param_names_string,
                                                     param_values=param_values_string)
 
-        # run command
-        current_path = os.getcwd()
-        os.chdir(self.problem.working_dir)
-        os.system(run_string)
-        os.chdir(current_path)
-        output_files = []
-        for file in self.output_files:
-            output_files.append(self.problem.working_dir + file)
-        result = self.parse_results(output_files, individual)
-        return result
+        try:
+            # run command
+            current_path = os.getcwd()
+            os.chdir(self.problem.working_dir)
+
+            out = subprocess.run(cmd_string, shell=True)
+            os.chdir(current_path)
+
+            if out.returncode != 0:
+                err = "Unknown error"
+                if out.stderr is not None:
+                    err = "Cannot run COMSOL Multiphysics.\n\n {}".format(out.stderr)
+
+                self.problem.logger.error(err)
+                raise RuntimeError(err)
+
+            output_files = []
+            for file in self.output_files:
+                output_files.append(self.problem.working_dir + file)
+            result = self.parse_results(output_files, individual)
+
+            return result
+        except Exception as e:
+            err = "Cannot run COMSOL Multiphysics.\n\n {}".format(e)
+            self.problem.logger.error(err)
+            raise RuntimeError(err)
 
 
 class RemoteExecutor(Executor):
@@ -120,8 +137,6 @@ class RemoteExecutor(Executor):
         Allows distributing of calculation of objective functions.
         """
 
-    # ToDo: Make inheritated classes: Matlab, Comsol ...
-
     def __init__(self, problem, command, files_to_server, files_from_server=None):
         super().__init__(problem)
 
@@ -231,6 +246,12 @@ class CondorJobExecutor(RemoteExecutor):
         # set default host
         self.options["hostname"] = config["condor_host"]
 
+        # set default requirements
+        self.requirements = ""
+        self.request_cpus = -1
+        self.request_memory = -1
+        self.hold_on_start = False
+
     @abstractmethod
     def _create_job_file(self, remote_dir, individual, client):
         pass
@@ -255,7 +276,6 @@ class CondorJobExecutor(RemoteExecutor):
                 self._transfer_files_to_remote(remote_dir, client)
 
                 # submit job
-                # print("_create_job_file -      {}".format(remote_dir))
                 try:
                     self._create_job_file(remote_dir, individual, client)
                 except AsyncResultTimeout as e:
@@ -277,39 +297,39 @@ class CondorJobExecutor(RemoteExecutor):
                 while run:
                     eventlog = client.root.eventlog(remote_dir)
                     for e in eventlog:
-                        if {e.timestamp, e.type} not in events:
-                            events.append({e.timestamp, e.type})
+                        if {e["timestamp"], e["type"]} not in events:
+                            events.append({e["timestamp"], e["type"]})
 
                     # print("len(events) = {}".format(len(events)))
                     if len(events) > 0:
                         for i in range(cnt, len(events)):
                             event = eventlog[i]
-                            tp = int(event.type)
+                            tp = event["type"]
 
                             args = ""
 
-                            if tp == 0:
+                            if tp == "submit":
                                 # SUBMIT
-                                if "ReturnValue" in event:
-                                    return_value = event["ReturnValue"]
-                            elif tp == 1:
+                                if "ReturnValue" in event["info"]:
+                                    return_value = event["info"]["ReturnValue"]
+                            elif tp == "execute":
                                 # EXECUTE
-                                if "ExecuteHost" in event:
-                                    args += "ExecuteHost: {}, ".format(parse_address(event["ExecuteHost"]))
-                            elif tp == 6:
+                                if "ExecuteHost" in event["info"]:
+                                    args += "ExecuteHost: {}, ".format(parse_address(event["info"]["ExecuteHost"]))
+                            elif tp == "image_size":
                                 # IMAGE_SIZE
                                 pass
-                            elif tp == 5:
+                            elif tp == "job_terminated":
                                 # JOB_TERMINATED
-                                if "ReturnValue" in event:
-                                    return_value = event["ReturnValue"]
+                                if "ReturnValue" in event["info"]:
+                                    return_value = event["info"]["ReturnValue"]
                                 run = False
-                            elif tp == 12:
+                            elif tp == "job_held":
                                 # JOB_HELD
-                                if "ReturnValue" in event:
-                                    return_value = event["ReturnValue"]
+                                if "ReturnValue" in event["info"]:
+                                    return_value = event["info"]["ReturnValue"]
 
-                                self.problem.logger.error("Job {} is '{}' at {}".format(event.type, event.type, event.type))
+                                self.problem.logger.error("Job {}.{} is '{}' at {}".format(event["cluster"], event["proc"], event["type"], ""))
                                 run = False
                                 # read log
                                 #content_log = self._read_file_from_remote("{}.log".format(self.output_files[0]),
@@ -323,7 +343,7 @@ class CondorJobExecutor(RemoteExecutor):
                             if len(args) > 0:
                                 args = args[:-2]
 
-                            self.problem.logger.info("Job {}.{} ({}) is '{}' at {}".format(event.cluster, event.proc, remote_dir, event.type, args))
+                            self.problem.logger.info("Job {}.{} ({}) is '{}' at {}".format(event["cluster"], event["proc"], remote_dir, event["type"], args))
                             # print("{}: {} ({})".format(eventlog[i].timestamp, eventlog[i].type, args))
 
                     if run:
@@ -373,20 +393,22 @@ class CondorJobExecutor(RemoteExecutor):
 
 
 class CondorPythonJobExecutor(CondorJobExecutor):
-    executable = textwrap.dedent("""\
-        #!/bin/sh
-        # args
-
-        python3 $@""")
-
-    def __init__(self, problem, script, parameter_file, output_files=None):
+    def __init__(self, problem, script, parameter_file, output_files=None, python_path="python3"):
         self.script = ntpath.basename(script)
         super().__init__(problem, [self.script], output_files)
+
         self.parameter_file = parameter_file
         copyfile(script, self.problem.working_dir + self.script)
 
+        self.executable = textwrap.dedent("""\
+            #!/bin/sh
+            # args
+
+            """ + python_path + """  $@""")
+
     def _create_job_file(self, remote_dir, individual, client):
         condor_output_files = self.output_files
+
         condor_input_files = [self.script]
         # create input file with parameters
 
@@ -405,32 +427,44 @@ class CondorPythonJobExecutor(CondorJobExecutor):
         # create executable
         self._create_file_on_remote("run.sh", self.executable, remote_dir=remote_dir, client=client)
 
+        # desc
+        desc = {}
+        desc["type"] = "python"
+        desc["extension"] = ".py"
+        desc["editor"] = True
+        desc["name"] = "Python"
+
         client.root.submit_job(remote_dir=remote_dir,
                                executable=client.root.artap_dir + os.sep + remote_dir + os.sep + "run.sh",
                                arguments=arguments,
                                input_files=condor_input_files,
-                               output_files=condor_output_files)
+                               output_files=condor_output_files,
+                               requirements=self.requirements,
+                               request_cpus=self.request_cpus,
+                               request_memory=self.request_memory,
+                               hold_on_start=self.hold_on_start,
+                               desc=desc)
 
 
 class CondorMatlabJobExecutor(CondorJobExecutor):
-    executable = textwrap.dedent("""\
-        #!/bin/sh
-        # args
-        s=$@
-
-        /opt/matlab-R2018b/bin/matlab -nodisplay -nosplash -nodesktop -r ${s%.m}""")
-
-    def __init__(self, problem, script, parameter_file, files_from_condor=None):
+    def __init__(self, problem, script, parameter_file, files_from_condor=None, matlab_path="/opt/matlab-R2018b/bin/matlab"):
         self.script = ntpath.basename(script)
         super().__init__(problem, [self.script], files_from_condor)
         self.parameter_file = parameter_file
         copyfile(script, self.problem.working_dir + self.script)
 
+        self.executable = textwrap.dedent("""\
+            #!/bin/sh
+            # args
+            s=$@
+
+            """ + matlab_path + """ -nodisplay -nosplash -nodesktop -r ${s%.m}""")
+
     def _create_job_file(self, remote_dir, individual, client):
         condor_output_files = self.output_files
         condor_input_files = [self.parameter_file, self.input_files[0]]
-        # create input file with parameters
 
+        # create input file with parameters
         if self.parameter_file:
             # parameters
             param_values_string = Executor._join_parameters_values(individual.vector, "\n")
@@ -440,27 +474,43 @@ class CondorMatlabJobExecutor(CondorJobExecutor):
         # create executable
         self._create_file_on_remote("run.sh", self.executable, remote_dir=remote_dir, client=client)
 
+        # desc
+        desc = {}
+        desc["type"] = "matlab"
+        desc["extension"] = ".m"
+        desc["editor"] = False
+        desc["name"] = "Matlab"
+
         client.root.submit_job(remote_dir=remote_dir,
                                executable=client.root.artap_dir + os.sep + remote_dir + os.sep + "run.sh",
                                arguments=self.script,
                                input_files=condor_input_files,
-                               output_files=condor_output_files)
+                               output_files=condor_output_files,
+                               requirements=self.requirements,
+                               request_cpus=self.request_cpus,
+                               request_memory=self.request_memory,
+                               hold_on_start=self.hold_on_start,
+                               desc=desc)
 
 
 class CondorComsolJobExecutor(CondorJobExecutor):
-    arguments = Template("-inputfile $input_file -nosave -pname $param_names -plist $param_values")
-    executable = textwrap.dedent("""\
-            #!/bin/sh
-            /opt/comsol-5.4/bin/comsol batch $@
-            """)
-
-    def __init__(self, problem, model_file, files_from_condor=None):
+    def __init__(self, problem, model_file, files_from_condor=None, comsol_path="/opt/comsol-5.4/bin/comsol"):
         self.model_file = ntpath.basename(model_file)
         super().__init__(problem, [self.model_file], files_from_condor)
         copyfile(model_file, self.problem.working_dir + self.model_file)
 
+        self.arguments = Template("-inputfile $input_file -nosave -pname $param_names -plist $param_values")
+        self.executable = textwrap.dedent("""\
+                #!/bin/sh
+                """ + comsol_path + """ batch $@
+                """)
+
+        self.request_cpus = 3
+        self.request_memory = 30
+
     def _create_job_file(self, remote_dir, individual, client):
         condor_output_files = self.output_files
+
         param_names_string = Executor._join_parameters_names(self.problem.parameters)
         param_values_string = Executor._join_parameters_values(individual.vector)
         arguments = self.arguments.substitute(input_file=os.path.basename(self.model_file),
@@ -470,10 +520,20 @@ class CondorComsolJobExecutor(CondorJobExecutor):
         # create executable
         self._create_file_on_remote("run.sh", self.executable, remote_dir=remote_dir, client=client)
 
+        # desc
+        desc = {}
+        desc["type"] = "comsol"
+        desc["extension"] = ".mph"
+        desc["editor"] = False
+        desc["name"] = "Comsol Multiphysics"
+
         client.root.submit_job(remote_dir=remote_dir,
                                executable=client.root.artap_dir + os.sep + remote_dir + os.sep + "run.sh",
                                arguments=arguments,
                                input_files=[self.model_file],
                                output_files=condor_output_files,
-                               request_cpus=2,
-                               request_memory=30)
+                               requirements=self.requirements,
+                               request_cpus=self.request_cpus,
+                               request_memory=self.request_memory,
+                               hold_on_start=self.hold_on_start,
+                               desc=desc)
