@@ -2,9 +2,10 @@
  Module is dedicated to describe optimization problem.
 """
 
-from .datastore import DataStore, DummyDataStore
-from .utils import ConfigDictionary
-from .surrogate import SurrogateModelEval
+from artap.datastore import FileDataStore, FileMode
+from artap.utils import ConfigDictionary
+from artap.surrogate import SurrogateModelEval
+from artap.monitor import MonitorService
 from abc import abstractmethod
 
 import logging
@@ -12,18 +13,7 @@ import datetime
 import tempfile
 import os
 import shutil
-
-from enum import Enum
-
-
-# ToDo: Inhere executors, remove enum
-
-class ProblemType(Enum):
-    comsol = 0
-    analytical = 1
-    agros = 2
-    matlab = 3
-    python = 4
+import atexit
 
 CRITICAL = logging.CRITICAL
 FATAL = logging.FATAL
@@ -40,9 +30,9 @@ _log_level = [CRITICAL, ERROR, WARNING, INFO, DEBUG]
 class Problem:
     """ The Class Problem Is a main class which collects information about optimization task """
 
-    __is_frozen = False
+    # __is_frozen = False
 
-    def __init__(self):
+    def __init__(self, **kwargs):
 
         self.options = ConfigDictionary()
         # options
@@ -61,18 +51,6 @@ class Problem:
         self.options.declare(name='save_data_files', default=False,
                              desc='Saving data from computation')
 
-        self.name: str = str()
-        self.description: str = str()
-        self.parameters: dict = dict()
-        self.costs: dict = dict()
-        self.data_store: DataStore
-        self.type = "None"
-        self.working_dir = tempfile.mkdtemp() + os.sep
-        self.output_files = None
-        self.executor = None
-        self.data_store = DummyDataStore(self)
-        self.is_working_dir_set = True
-
         # tmp name
         d = datetime.datetime.now()
         ts = d.strftime("{}-%f".format(self.__class__.__name__))
@@ -97,18 +75,31 @@ class Problem:
             # add StreamHandler to logger
             self.logger.addHandler(stream_handler)
 
-        # self.id = self.data_store.get_id()
-
         self.logger.debug("START")
-        # self.logger.debug('This message should go to the log file')
-        # self.logger.info('So should this')
-        # self.logger.warning('And this, too')
+
+        self.name: str = str()
+        self.description: str = str()
+        self.parameters: dict = dict()
+        self.costs: dict = dict()
+
+        # populations
+        self.populations = []
+
+        self.data_store = None
+        self.monitor_service = MonitorService(self)
+        self.executor = None
+
+        self.output_files = None
+
+        self.working_dir = tempfile.gettempdir() + os.sep + "artap-{}".format(ts) + os.sep
+        os.mkdir(self.working_dir)
 
         # surrogate model (default - only simple eval)
         self.surrogate = SurrogateModelEval(self)
         self.signs = []
-        self._freeze()
-        self.set()
+
+        # self._freeze()
+        self.set(**kwargs)
         for cost in self.costs:
             if 'criteria' in cost:
                 if cost['criteria'] == 'minimize':
@@ -118,12 +109,23 @@ class Problem:
             else:
                 self.signs.append(1)
 
-    def __del__(self):
-        if not self.is_working_dir_set:
+        # clean up
+        atexit.register(self.cleanup)
+
+    def cleanup(self):
+        if self.data_store:
+            self.data_store.destroy()
+
+        if self.monitor_service.server is not None:
+            self.monitor_service.server.close()
+            del self.monitor_service.server
+            self.monitor_service.server = None
+
+        if self.working_dir.startswith(tempfile.gettempdir() + os.sep + "artap-"):
             shutil.rmtree(self.working_dir)
 
     @abstractmethod
-    def set(self):
+    def set(self, **kwargs):
         pass
 
     def parameters_len(self):
@@ -160,17 +162,17 @@ class Problem:
         return p_types
 
     @abstractmethod
-    def evaluate(self, x: list):
-        """ :param x: list of the variables """
+    def evaluate(self, x):
+        """ :param x: individual """
         pass
 
-    def evaluate_constraints(self, x: list):
-        """ :param x: list of the variables """
+    def evaluate_constraints(self, x):
+        """ :param x: individual """
         pass
 
     def __setattr__(self, key, value):
-        if self.__is_frozen and not hasattr(self, key):
-            raise TypeError(" %r is a frozen class" % self)
+        # if self.__is_frozen and not hasattr(self, key):
+        #     raise TypeError(" %r is a frozen class" % self)
         object.__setattr__(self, key, value)
 
         # working dir must be set
@@ -183,7 +185,19 @@ class Problem:
                 file_handler.setFormatter(self.formatter)
                 # add FileHandler to logger
                 self.logger.addHandler(file_handler)
-                self.is_working_dir_set = True
 
-    def _freeze(self):
-        self.__is_frozen = True
+    # def _freeze(self):
+    #     self.__is_frozen = True
+
+
+class ProblemViewDataStore(Problem):
+    def __init__(self, database_name):
+        super().__init__()
+
+        self.data_store = FileDataStore(self, database_name=database_name, mode=FileMode.READ)
+
+    def set(self, **kwargs):
+        pass
+
+    def evaluate(self, x):
+        pass
