@@ -26,14 +26,14 @@ class TestJob(unittest.TestCase):
 
     def test_sweep_evaluate_parallel(self):
         problem = SweepProblem()
-        gen = LHSGeneration(problem.parameters)
-        gen.init(4)
+        generator = LHSGeneration(problem.parameters)
+        generator.init(4)
 
-        algorithm = SweepAlgorithm(problem, generator=gen)
+        algorithm = SweepAlgorithm(problem, generator=generator)
         algorithm.options['max_processes'] = 2
         algorithm.run()
 
-        individuals = problem.data_store.populations[-1].individuals
+        individuals = problem.populations[-1].individuals
         # values
         self.assertEqual(len(individuals), 4)
         self.assertTrue(problem.parameters[0]['bounds'][0] <= individuals[0].vector[0] <=
@@ -54,7 +54,7 @@ class TestJob(unittest.TestCase):
         algorithm = SweepAlgorithm(problem, generator=gen)
         algorithm.run()
 
-        individuals = problem.data_store.populations[-1].individuals
+        individuals = problem.populations[-1].individuals
         self.assertEqual(individuals[0].costs, [9])
         self.assertEqual(individuals[1].costs, [22])
 
